PCB Environment: dsn Namespace Reference

PCB Environment 2

Loading...
Searching...
No Matches
Data Structures | Functions
dsn Namespace Reference

## Data Structures
struct | BBox
struct | PCB
struct | Layer
struct | Segment
struct | Via
struct | Track
struct | Connection
struct | Net
struct | Path
struct | Shape
struct | Padstack
struct | Pin
struct | Image
struct | Structure
struct | Placement
struct | Data

## Functions
BBox | get_bounding_box (const std::vector< double > &xy, double expansion)

## Function Documentation

## ◆ get_bounding_box()

BBox dsn::get_bounding_box | ( | const std::vector< double > & | xy,
|  | double | expansion )